board: freescale: typo volatge

%s/volatge/voltage/g

Signed-off-by: Heinrich Schuchardt <heinrich.schuchardt@canonical.com>
Acked-by: Peng Fan <peng.fan@nxp.com>
diff --git a/board/freescale/ls1088a/ls1088a.c b/board/freescale/ls1088a/ls1088a.c
index 9f4eb48..9606434 100644
--- a/board/freescale/ls1088a/ls1088a.c
+++ b/board/freescale/ls1088a/ls1088a.c
@@ -690,7 +690,7 @@
 	dm_i2c_read(dev, PMBUS_CMD_READ_VOUT, (void *)&vcode, 2);
 #endif
 	if (ret) {
-		printf("VID: failed to read the volatge\n");
+		printf("VID: failed to read the voltage\n");
 		return ret;
 	}
 
@@ -716,11 +716,11 @@
 				   (void *)&buff, 5);
 #endif
 	if (ret) {
-		printf("VID: I2C failed to write to the volatge regulator\n");
+		printf("VID: I2C failed to write to the voltage regulator\n");
 		return -1;
 	}
 
 	/* Wait for the volatge to get to the desired value */
 	do {
 		vdd_last = get_serdes_volt();
 		if (vdd_last < 0) {
@@ -778,7 +778,7 @@
 		return -1;
 	}
 
 	/* Wait for the volatge to get to the desired value */
 	udelay(10000);
 
 	return 1;
@@ -716,11 +716,11 @@
 	}
 
-	/* Wait for the volatge to get to the desired value */
+	/* Wait for the voltage to get to the desired value */
 	do {
 		vdd_last = get_serdes_volt();
@@ -778,7 +778,7 @@
 	}
 
-	/* Wait for the volatge to get to the desired value */
+	/* Wait for the voltage to get to the desired value */
 	udelay(10000);
 